#!/usr/bin/python

import re

class PciDevice:
    def __init__(self, codename, regex, drivers=None, supported=True, title=None):
        # Short codename, suitable for prepending to bug reports
        self.name = codename

        # Long Marketing name
        self.title = title

        # Pattern to seek in lspci or other text output
        self.regex = regex

        # Set of open (DDX) and/or proprietary drivers that should work for this hardware
        # If none are listed, then -vesa/-fbdev should be used
        self.drivers = drivers

        # Whether Ubuntu-X provides development support for the hardware (with
        # any video driver).  If unsupported, we redirect bug reporters upstream
        # instead of filing bugs at Launchpad, and we do not backport patches or
        # customize any settings.
        self.supported = supported

        self.__rc = None

    @property
    def rc(self):
        if self.__rc is None:
            self.__rc = re.compile(self.regex, re.IGNORECASE)
        return self.__rc

pci_devices = [
    PciDevice('i810',       '(8086:7121)',       [], supported=False),
    PciDevice('i810dc',     '(8086:7123)',       [], supported=False),
    PciDevice('i810e',      '(8086:7125)',       [], supported=False),
    PciDevice('i815',       '(8086:1132|82815)', [], supported=False),
    PciDevice('i830',       '(8086:3577|82830)', ['xserver-xorg-video-intel'], supported=False),
    PciDevice('i845',       '(8086:2562|82845G)',['xserver-xorg-video-intel'], supported=False),
    PciDevice('i855',       '(8086:3582|855GM)', ['xserver-xorg-video-intel'], supported=False),
    PciDevice('i865',       '(8086:2572|82865G)',['xserver-xorg-video-intel'], supported=False),
    PciDevice('i915g',      '(8086:2582)',       ['xserver-xorg-video-intel']),
    PciDevice('i915gm',     '(8086:2592|915GM)', ['xserver-xorg-video-intel']),
    PciDevice('e7221',      '(8086:258a)',       ['xserver-xorg-video-intel'], supported=False),
    PciDevice('i945g',      '(8086:2772|945G[ \/]|82945G[ \/])' ),
    PciDevice('i945gm',     '(8086:27a2|945GM[ \/]|82945GM[ \/])', ['xserver-xorg-video-intel']),
    PciDevice('i945gme',    '(8086:27ae|945GME|82945GME)', ['xserver-xorg-video-intel']),
    PciDevice('IGDg',       '(8086:a001)',       ['xserver-xorg-video-intel']),
    PciDevice('IGDgm',      '(8086:a011)',       ['xserver-xorg-video-intel']),
    PciDevice('pineviewg',  '(8086:a001)',       ['xserver-xorg-video-intel']),
    PciDevice('pineviewgm', '(8086:a011)',       ['xserver-xorg-video-intel']),
    PciDevice('i946gz',     '(8086:2972|82946GZ)', ['xserver-xorg-video-intel']),
    PciDevice('g35',        '(8086:2982|82G35)', ['xserver-xorg-video-intel']),
    PciDevice('i965q',      '(8086:2992|Q965)',  ['xserver-xorg-video-intel']),
    PciDevice('i965g',      '(8086:29a2|G965)',  ['xserver-xorg-video-intel']),
    PciDevice('g33',        '(8086:29c2|82G33)', ['xserver-xorg-video-intel']),
    PciDevice('q35',        '(8086:29b2)',       ['xserver-xorg-video-intel']),
    PciDevice('q33',        '(8086:29d2)',       ['xserver-xorg-video-intel']),
    PciDevice('i965gm',     '(8086:2a02|GM965)', ['xserver-xorg-video-intel']),
    PciDevice('i965gme',    '(8086:2a12)',       ['xserver-xorg-video-intel']),
    PciDevice('gm45',       '(8086:2a42)',       ['xserver-xorg-video-intel']),
    PciDevice('IGDeg',      '(8086:2e02)',       ['xserver-xorg-video-intel']),
    PciDevice('q45',        '(8086:2e12)',       ['xserver-xorg-video-intel']),
    PciDevice('g45',        '(8086:2e22)',       ['xserver-xorg-video-intel']),
    PciDevice('g41',        '(8086:2e32)',       ['xserver-xorg-video-intel']),
    PciDevice('b43',        '(8086:2e42)',       ['xserver-xorg-video-intel']),
    PciDevice('clarkdale',  '(8086:0042)',       ['xserver-xorg-video-intel']),
    PciDevice('arrandale',  '(8086:0046)',       ['xserver-xorg-video-intel']),
    PciDevice('snb-gt1',    '(8086:0102)',       ['xserver-xorg-video-intel']),
    PciDevice('snb-m-gt1',  '(8086:0106)',       ['xserver-xorg-video-intel']),
    PciDevice('snb-s',      '(8086:010a)',       ['xserver-xorg-video-intel']),
    PciDevice('snb-gt2',    '(8086:0112)',       ['xserver-xorg-video-intel']),
    PciDevice('snb-m-gt2',  '(8086:0116)',       ['xserver-xorg-video-intel']),
    PciDevice('snb-gt2+',   '(8086:0122)',       ['xserver-xorg-video-intel']),
    PciDevice('snb-m-gt2+', '(8086:0126)',       ['xserver-xorg-video-intel']),

    # ATI
    PciDevice('RV380',      '(1002:3150)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV380',      '(1002:3151)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV380',      '(1002:3152)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV380',      '(1002:3154)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV380',      '(1002:3e50)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV380',      '(1002:3e54)', ['xserver-xorg-video-ati'] ),
    PciDevice('RS100',      '(1002:4136)', ['xserver-xorg-video-ati'], supported=False ),
    PciDevice('RS200',      '(1002:4137)', ['xserver-xorg-video-ati'], supported=False ),
    PciDevice('R300',       '(1002:4144)', ['xserver-xorg-video-ati'] ),
    PciDevice('R300',       '(1002:4145)', ['xserver-xorg-video-ati'] ),
    PciDevice('R300',       '(1002:4146)', ['xserver-xorg-video-ati'] ),
    PciDevice('R300',       '(1002:4147)', ['xserver-xorg-video-ati'] ),
    PciDevice('R350',       '(1002:4148)', ['xserver-xorg-video-ati'] ),
    PciDevice('R350',       '(1002:4149)', ['xserver-xorg-video-ati'] ),
    PciDevice('R350',       '(1002:414a)', ['xserver-xorg-video-ati'] ),
    PciDevice('R350',       '(1002:414b)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV350',      '(1002:4150)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV350',      '(1002:4151)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV360',      '(1002:4152)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV350',      '(1002:4153)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV350',      '(1002:4154)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV350',      '(1002:4155)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV350',      '(1002:4156)', ['xserver-xorg-video-ati'] ),
    PciDevice('RS250',      '(1002:4237)', ['xserver-xorg-video-ati'], supported=False ),
    PciDevice('R200',       '(1002:4242)', ['xserver-xorg-video-ati'], supported=False ),
    PciDevice('R200',       '(1002:4243)', ['xserver-xorg-video-ati'], supported=False ),
    PciDevice('RS100',      '(1002:4336)', ['xserver-xorg-video-ati'], supported=False ),
    PciDevice('RS200',      '(1002:4337)', ['xserver-xorg-video-ati'], supported=False ),
    PciDevice('RS250',      '(1002:4437)', ['xserver-xorg-video-ati'], supported=False ),
    PciDevice('RV250',      '(1002:4966)', ['xserver-xorg-video-ati'], supported=False ),
    PciDevice('RV250',      '(1002:4967)', ['xserver-xorg-video-ati'], supported=False ),
    PciDevice('R420',       '(1002:4a48)', ['xserver-xorg-video-ati'] ),
    PciDevice('R420',       '(1002:4a49)', ['xserver-xorg-video-ati'] ),
    PciDevice('R420',       '(1002:4a4a)', ['xserver-xorg-video-ati'] ),
    PciDevice('R420',       '(1002:4a4b)', ['xserver-xorg-video-ati'] ),
    PciDevice('R420',       '(1002:4a4c)', ['xserver-xorg-video-ati'] ),
    PciDevice('R420',       '(1002:4a4d)', ['xserver-xorg-video-ati'] ),
    PciDevice('R420',       '(1002:4a4e)', ['xserver-xorg-video-ati'] ),
    PciDevice('R420',       '(1002:4a4f)', ['xserver-xorg-video-ati'] ),
    PciDevice('R481',       '(1002:4b48)', ['xserver-xorg-video-ati'] ),
    PciDevice('R481',       '(1002:4b49)', ['xserver-xorg-video-ati'] ),
    PciDevice('R481',       '(1002:4a4a)', ['xserver-xorg-video-ati'] ),
    PciDevice('R481',       '(1002:4a4b)', ['xserver-xorg-video-ati'] ),
    PciDevice('R481',       '(1002:4a4c)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV200',      '(1002:4c57)', ['xserver-xorg-video-ati'], supported=False ),
    PciDevice('RV200',      '(1002:4c58)', ['xserver-xorg-video-ati'], supported=False ),
    PciDevice('RV100',      '(1002:4c59)', ['xserver-xorg-video-ati'], supported=False ),
    PciDevice('RV100',      '(1002:4c5a)', ['xserver-xorg-video-ati'], supported=False ),
    PciDevice('RV250',      '(1002:4c64)', ['xserver-xorg-video-ati'], supported=False ),
    PciDevice('RV250',      '(1002:4c66)', ['xserver-xorg-video-ati'], supported=False ),
    PciDevice('RV250',      '(1002:4c67)', ['xserver-xorg-video-ati'], supported=False ),
    PciDevice('R300',       '(1002:4e44)', ['xserver-xorg-video-ati'] ),
    PciDevice('R300',       '(1002:4e45)', ['xserver-xorg-video-ati'] ),
    PciDevice('R300',       '(1002:4e46)', ['xserver-xorg-video-ati'] ),
    PciDevice('R300',       '(1002:4e47)', ['xserver-xorg-video-ati'] ),
    PciDevice('R350',       '(1002:4e48)', ['xserver-xorg-video-ati'] ),
    PciDevice('R350',       '(1002:4e49)', ['xserver-xorg-video-ati'] ),
    PciDevice('R360',       '(1002:4e4a)', ['xserver-xorg-video-ati'] ),
    PciDevice('R350',       '(1002:4e4b)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV350',      '(1002:4e50)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV350',      '(1002:4e51)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV350',      '(1002:4e52)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV350',      '(1002:4e53)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV350',      '(1002:4e54)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV350',      '(1002:4e56)', ['xserver-xorg-video-ati'] ),
    PciDevice('R200',       '(1002:5148)', ['xserver-xorg-video-ati'], supported=False ),
    PciDevice('R200',       '(1002:514c)', ['xserver-xorg-video-ati'], supported=False ),
    PciDevice('R200',       '(1002:514d)', ['xserver-xorg-video-ati'], supported=False ),
    PciDevice('RV200',      '(1002:5157)', ['xserver-xorg-video-ati'], supported=False ),
    PciDevice('RV200',      '(1002:5158)', ['xserver-xorg-video-ati'], supported=False ),
    PciDevice('RV100',      '(1002:5159)', ['xserver-xorg-video-ati'], supported=False ),
    PciDevice('RV100',      '(1002:515a)', ['xserver-xorg-video-ati'], supported=False ),
    PciDevice('RN50',       '(1002:515e)', ['xserver-xorg-video-ati'], supported=False ),
    PciDevice('RV370',      '(1002:5160)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV370',      '(1002:5162)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV370',      '(1002:5164)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV380',      '(1002:5460)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV380',      '(1002:5462)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV380',      '(1002:5464)', ['xserver-xorg-video-ati'] ),
    PciDevice('R423',       '(1002:5548)', ['xserver-xorg-video-ati'] ),
    PciDevice('R423',       '(1002:5549)', ['xserver-xorg-video-ati'] ),
    PciDevice('R423',       '(1002:554a)', ['xserver-xorg-video-ati'] ),
    PciDevice('R423',       '(1002:554b)', ['xserver-xorg-video-ati'] ),
    PciDevice('R430',       '(1002:554c)', ['xserver-xorg-video-ati'] ),
    PciDevice('R430',       '(1002:554d)', ['xserver-xorg-video-ati'] ),
    PciDevice('R430',       '(1002:554e)', ['xserver-xorg-video-ati'] ),
    PciDevice('R430',       '(1002:554f)', ['xserver-xorg-video-ati'] ),
    PciDevice('R423',       '(1002:5550)', ['xserver-xorg-video-ati'] ),
    PciDevice('R423',       '(1002:5551)', ['xserver-xorg-video-ati'] ),
    PciDevice('R423',       '(1002:5552)', ['xserver-xorg-video-ati'] ),
    PciDevice('R423',       '(1002:5554)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV410',      '(1002:564a)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV410',      '(1002:564b)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV410',      '(1002:5652)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV410',      '(1002:5653)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV410',      '(1002:5657)', ['xserver-xorg-video-ati'] ),
    PciDevice('RS300',      '(1002:5834)', ['xserver-xorg-video-ati'] ),
    PciDevice('RS300',      '(1002:5835)', ['xserver-xorg-video-ati'] ),
    PciDevice('RS480',      '(1002:5954)', ['xserver-xorg-video-ati'] ),
    PciDevice('RS480',      '(1002:5955)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV280',      '(1002:5960)', ['xserver-xorg-video-ati'], supported=False ),
    PciDevice('RV280',      '(1002:5961)', ['xserver-xorg-video-ati'], supported=False ),
    PciDevice('RV280',      '(1002:5962)', ['xserver-xorg-video-ati'], supported=False ),
    PciDevice('RV280',      '(1002:5964)', ['xserver-xorg-video-ati'], supported=False ),
    PciDevice('RV280',      '(1002:5965)', ['xserver-xorg-video-ati'], supported=False ),
    PciDevice('RN50',       '(1002:5969)', ['xserver-xorg-video-ati'], supported=False ),
    PciDevice('RS482',      '(1002:5974)', ['xserver-xorg-video-ati'] ),
    PciDevice('RS485',      '(1002:5975)', ['xserver-xorg-video-ati'] ),
    PciDevice('RS400',      '(1002:5a41)', ['xserver-xorg-video-ati'] ),
    PciDevice('RS400',      '(1002:5a42)', ['xserver-xorg-video-ati'] ),
    PciDevice('RC410',      '(1002:5a61)', ['xserver-xorg-video-ati'] ),
    PciDevice('RC410',      '(1002:5a62)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV370',      '(1002:5b60)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV370',      '(1002:5b62)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV370',      '(1002:5b63)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV370',      '(1002:5b64)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV370',      '(1002:5b65)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV280',      '(1002:5c61)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV280',      '(1002:5c63)', ['xserver-xorg-video-ati'] ),
    PciDevice('R430',       '(1002:5d48)', ['xserver-xorg-video-ati'] ),
    PciDevice('R430',       '(1002:5d49)', ['xserver-xorg-video-ati'] ),
    PciDevice('R430',       '(1002:5d4a)', ['xserver-xorg-video-ati'] ),
    PciDevice('R480',       '(1002:5d4c)', ['xserver-xorg-video-ati'] ),
    PciDevice('R480',       '(1002:5d4d)', ['xserver-xorg-video-ati'] ),
    PciDevice('R480',       '(1002:5d4e)', ['xserver-xorg-video-ati'] ),
    PciDevice('R480',       '(1002:5d4f)', ['xserver-xorg-video-ati'] ),
    PciDevice('R480',       '(1002:5d50)', ['xserver-xorg-video-ati'] ),
    PciDevice('R480',       '(1002:5d52)', ['xserver-xorg-video-ati'] ),
    PciDevice('R423',       '(1002:5d57)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV410',      '(1002:5e48)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV410',      '(1002:5e4a)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV410',      '(1002:5e4b)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV410',      '(1002:5e4c)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV410',      '(1002:5e4d)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV410',      '(1002:5e4f)', ['xserver-xorg-video-ati'] ),
    PciDevice('R520',       '(1002:7100)', ['xserver-xorg-video-ati'] ),
    PciDevice('R520',       '(1002:7101)', ['xserver-xorg-video-ati'] ),
    PciDevice('R520',       '(1002:7102)', ['xserver-xorg-video-ati'] ),
    PciDevice('R520',       '(1002:7103)', ['xserver-xorg-video-ati'] ),
    PciDevice('R520',       '(1002:7104)', ['xserver-xorg-video-ati'] ),
    PciDevice('R520',       '(1002:7105)', ['xserver-xorg-video-ati'] ),
    PciDevice('R520',       '(1002:7106)', ['xserver-xorg-video-ati'] ),
    PciDevice('R520',       '(1002:7108)', ['xserver-xorg-video-ati'] ),
    PciDevice('R520',       '(1002:7109)', ['xserver-xorg-video-ati'] ),
    PciDevice('R520',       '(1002:710a)', ['xserver-xorg-video-ati'] ),
    PciDevice('R520',       '(1002:710b)', ['xserver-xorg-video-ati'] ),
    PciDevice('R520',       '(1002:710c)', ['xserver-xorg-video-ati'] ),
    PciDevice('R520',       '(1002:710e)', ['xserver-xorg-video-ati'] ),
    PciDevice('R520',       '(1002:710f)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV515',      '(1002:7140)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV515',      '(1002:7141)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV515',      '(1002:7142)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV515',      '(1002:7143)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV515',      '(1002:7144)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV515',      '(1002:7145)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV515',      '(1002:7146)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV515',      '(1002:7147)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV515',      '(1002:7149)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV515',      '(1002:714a)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV515',      '(1002:714b)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV515',      '(1002:714c)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV515',      '(1002:714d)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV515',      '(1002:714e)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV515',      '(1002:714f)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV515',      '(1002:7151)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV515',      '(1002:7152)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV515',      '(1002:7153)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV515',      '(1002:715e)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV515',      '(1002:715f)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV515',      '(1002:7180)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV515',      '(1002:7181)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV515',      '(1002:7183)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV515',      '(1002:7186)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV515',      '(1002:7187)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV515',      '(1002:7188)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV515',      '(1002:718a)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV515',      '(1002:718b)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV515',      '(1002:718c)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV515',      '(1002:718d)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV515',      '(1002:718f)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV515',      '(1002:7193)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV515',      '(1002:7196)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV515',      '(1002:719b)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV515',      '(1002:719f)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV530',      '(1002:71c0)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV530',      '(1002:71c1)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV530',      '(1002:71c2)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV530',      '(1002:71c3)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV530',      '(1002:71c4)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV530',      '(1002:71c5)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV530',      '(1002:71c6)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV530',      '(1002:71c7)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV530',      '(1002:71cd)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV530',      '(1002:71ce)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV530',      '(1002:71d2)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV530',      '(1002:71d4)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV530',      '(1002:71d5)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV530',      '(1002:71d6)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV530',      '(1002:71da)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV530',      '(1002:71de)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV515',      '(1002:7200)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV515',      '(1002:7210)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV515',      '(1002:7211)', ['xserver-xorg-video-ati'] ),
    PciDevice('R580',       '(1002:7240)', ['xserver-xorg-video-ati'] ),
    PciDevice('R580',       '(1002:7243)', ['xserver-xorg-video-ati'] ),
    PciDevice('R580',       '(1002:7244)', ['xserver-xorg-video-ati'] ),
    PciDevice('R580',       '(1002:7245)', ['xserver-xorg-video-ati'] ),
    PciDevice('R580',       '(1002:7246)', ['xserver-xorg-video-ati'] ),
    PciDevice('R580',       '(1002:7247)', ['xserver-xorg-video-ati'] ),
    PciDevice('R580',       '(1002:7248)', ['xserver-xorg-video-ati'] ),
    PciDevice('R580',       '(1002:7249)', ['xserver-xorg-video-ati'] ),
    PciDevice('R580',       '(1002:724a)', ['xserver-xorg-video-ati'] ),
    PciDevice('R580',       '(1002:724b)', ['xserver-xorg-video-ati'] ),
    PciDevice('R580',       '(1002:724c)', ['xserver-xorg-video-ati'] ),
    PciDevice('R580',       '(1002:724d)', ['xserver-xorg-video-ati'] ),
    PciDevice('R580',       '(1002:724e)', ['xserver-xorg-video-ati'] ),
    PciDevice('R580',       '(1002:724f)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV570',      '(1002:7280)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV560',      '(1002:7281)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV560',      '(1002:7283)', ['xserver-xorg-video-ati'] ),
    PciDevice('R580',       '(1002:7284)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV560',      '(1002:7287)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV570',      '(1002:7288)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV570',      '(1002:7289)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV570',      '(1002:728b)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV570',      '(1002:728c)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV560',      '(1002:7290)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV560',      '(1002:7291)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV560',      '(1002:7293)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV560',      '(1002:7297)', ['xserver-xorg-video-ati'] ),
    PciDevice('RS350',      '(1002:7834)', ['xserver-xorg-video-ati'] ),
    PciDevice('RS350',      '(1002:7835)', ['xserver-xorg-video-ati'] ),
    PciDevice('RS690',      '(1002:791e)', ['xserver-xorg-video-ati'] ),
    PciDevice('RS690',      '(1002:791f)', ['xserver-xorg-video-ati'] ),
    PciDevice('RS600',      '(1002:793f)', ['xserver-xorg-video-ati'] ),
    PciDevice('RS600',      '(1002:7941)', ['xserver-xorg-video-ati'] ),
    PciDevice('RS600',      '(1002:7942)', ['xserver-xorg-video-ati'] ),
    PciDevice('RS740',      '(1002:796c)', ['xserver-xorg-video-ati'] ),
    PciDevice('RS740',      '(1002:796d)', ['xserver-xorg-video-ati'] ),
    PciDevice('RS740',      '(1002:796e)', ['xserver-xorg-video-ati'] ),
    PciDevice('RS740',      '(1002:796f)', ['xserver-xorg-video-ati'] ),
    PciDevice('R600',       '(1002:9400)', ['xserver-xorg-video-ati'] ),
    PciDevice('R600',       '(1002:9401)', ['xserver-xorg-video-ati'] ),
    PciDevice('R600',       '(1002:9402)', ['xserver-xorg-video-ati'] ),
    PciDevice('R600',       '(1002:9403)', ['xserver-xorg-video-ati'] ),
    PciDevice('R600',       '(1002:9405)', ['xserver-xorg-video-ati'] ),
    PciDevice('R600',       '(1002:940a)', ['xserver-xorg-video-ati'] ),
    PciDevice('R600',       '(1002:940b)', ['xserver-xorg-video-ati'] ),
    PciDevice('R600',       '(1002:940f)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV770',      '(1002:9440)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV770',      '(1002:9441)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV770',      '(1002:9442)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV770',      '(1002:9443)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV770',      '(1002:9444)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV770',      '(1002:9446)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV770',      '(1002:944a)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV770',      '(1002:944b)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV770',      '(1002:944c)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV770',      '(1002:944e)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV770',      '(1002:9450)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV770',      '(1002:9452)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV770',      '(1002:9456)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV770',      '(1002:945a)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV770',      '(1002:945b)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV790',      '(1002:9460)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV790',      '(1002:9462)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV770',      '(1002:946a)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV770',      '(1002:946b)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV770',      '(1002:947a)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV770',      '(1002:947b)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV730',      '(1002:9480)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV730',      '(1002:9487)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV730',      '(1002:9488)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV730',      '(1002:9489)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV730',      '(1002:948f)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV730',      '(1002:9490)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV730',      '(1002:9491)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV730',      '(1002:9495)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV730',      '(1002:9498)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV730',      '(1002:949c)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV730',      '(1002:949e)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV730',      '(1002:949f)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV740',      '(1002:94a0)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV740',      '(1002:94a1)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV740',      '(1002:94a3)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV740',      '(1002:94b1)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV740',      '(1002:94b3)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV740',      '(1002:94b4)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV740',      '(1002:94b5)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV740',      '(1002:94b9)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV610',      '(1002:94c0)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV610',      '(1002:94c1)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV610',      '(1002:94c3)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV610',      '(1002:94c4)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV610',      '(1002:94c5)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV610',      '(1002:94c6)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV610',      '(1002:94c7)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV610',      '(1002:94c8)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV610',      '(1002:94c9)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV610',      '(1002:94cb)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV610',      '(1002:94cc)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV610',      '(1002:94cd)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV670',      '(1002:9500)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV670',      '(1002:9501)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV670',      '(1002:9504)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV670',      '(1002:9505)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV670',      '(1002:9506)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV670',      '(1002:9507)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV670',      '(1002:9508)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV670',      '(1002:9509)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV670',      '(1002:950f)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV670',      '(1002:9511)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV670',      '(1002:9515)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV670',      '(1002:9517)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV670',      '(1002:9519)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV710',      '(1002:9540)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV710',      '(1002:9541)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV710',      '(1002:954e)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV710',      '(1002:954f)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV710',      '(1002:9552)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV710',      '(1002:9553)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV710',      '(1002:9555)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV710',      '(1002:9557)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV630',      '(1002:9580)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV630',      '(1002:9581)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV630',      '(1002:9583)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV630',      '(1002:9586)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV630',      '(1002:9587)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV630',      '(1002:9588)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV630',      '(1002:9589)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV630',      '(1002:958a)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV630',      '(1002:958b)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV630',      '(1002:958c)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV630',      '(1002:958d)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV630',      '(1002:958e)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV630',      '(1002:958f)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV710',      '(1002:9542)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV620',      '(1002:95c0)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV620',      '(1002:95c2)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV620',      '(1002:95c4)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV620',      '(1002:95c5)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV620',      '(1002:95c6)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV620',      '(1002:95c7)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV620',      '(1002:95c9)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV620',      '(1002:95cc)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV620',      '(1002:95cd)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV620',      '(1002:95ce)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV620',      '(1002:95cf)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV635',      '(1002:9590)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV635',      '(1002:9596)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV635',      '(1002:9597)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV635',      '(1002:9598)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV635',      '(1002:9599)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV635',      '(1002:9591)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV635',      '(1002:9593)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV635',      '(1002:9595)', ['xserver-xorg-video-ati'] ),
    PciDevice('RV635',      '(1002:959b)', ['xserver-xorg-video-ati'] ),
    PciDevice('RS780',      '(1002:9610)', ['xserver-xorg-video-ati'] ),
    PciDevice('RS780',      '(1002:9611)', ['xserver-xorg-video-ati'] ),
    PciDevice('RS780',      '(1002:9612)', ['xserver-xorg-video-ati'] ),
    PciDevice('RS780',      '(1002:9613)', ['xserver-xorg-video-ati'] ),
    PciDevice('RS780',      '(1002:9614)', ['xserver-xorg-video-ati'] ),
    PciDevice('RS780',      '(1002:9615)', ['xserver-xorg-video-ati'] ),
    PciDevice('RS780',      '(1002:9616)', ['xserver-xorg-video-ati'] ),
    PciDevice('RS880',      '(1002:9710)', ['xserver-xorg-video-ati'] ),
    PciDevice('RS880',      '(1002:9711)', ['xserver-xorg-video-ati'] ),
    PciDevice('RS880',      '(1002:9712)', ['xserver-xorg-video-ati'] ),
    PciDevice('RS880',      '(1002:9713)', ['xserver-xorg-video-ati'] ),
    PciDevice('RS880',      '(1002:9714)', ['xserver-xorg-video-ati'] ),
    PciDevice('RS880',      '(1002:9715)', ['xserver-xorg-video-ati'] ),

    # Nvidia
    # TODO: Switch to use of codenames from http://nouveau.freedesktop.org/wiki/CodeNames
    # Or use http://pci-ids.ucw.cz/read/PC/10de
    PciDevice('NV40',                                    '(10de:0040)',  ['nvidia-graphics-drivers'] ),
    PciDevice('NV40',                                    '(10de:0041)',  ['nvidia-graphics-drivers'] ),
    PciDevice('NV40.2',                                  '(10de:0042)',  ['nvidia-graphics-drivers'] ),
    PciDevice('NV40.3',                                  '(10de:0043)',  ['nvidia-graphics-drivers'] ),
    PciDevice('NV40',                                    '(10de:0044)',  ['nvidia-graphics-drivers'] ),
    PciDevice('NV40',                                    '(10de:0045)',  ['nvidia-graphics-drivers'] ),
    PciDevice('NV45',                                    '(10de:0046)',  ['nvidia-graphics-drivers'] ),
    PciDevice('NV40',                                    '(10de:0047)',  ['nvidia-graphics-drivers'] ),
    PciDevice('NV40',                                    '(10de:0048)',  ['nvidia-graphics-drivers'] ),
    PciDevice('G70',                                     '(10de:0090)',  ['nvidia-graphics-drivers'] ),
    PciDevice('G70',                                     '(10de:0091)',  ['nvidia-graphics-drivers'] ),
    PciDevice('G70',                                     '(10de:0092)',  ['nvidia-graphics-drivers'] ),
    PciDevice('G70',                                     '(10de:0093)',  ['nvidia-graphics-drivers'] ),
    PciDevice('G70',                                     '(10de:0095)',  ['nvidia-graphics-drivers'] ),
    PciDevice('G70',                                     '(10de:0098)',  ['nvidia-graphics-drivers'] ),
    PciDevice('G70',                                     '(10de:0099)',  ['nvidia-graphics-drivers'] ),
    PciDevice('NV41',                                    '(10de:00C0)',  ['nvidia-graphics-drivers'] ),
    PciDevice('NV41.1',                                  '(10de:00C1)',  ['nvidia-graphics-drivers'] ),
    PciDevice('NV41.2',                                  '(10de:00C2)',  ['nvidia-graphics-drivers'] ),
    PciDevice('NV42',                                    '(10de:00C3)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce Go 6800',                         '(10de:00C8)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce Go 6800 Ultra',                   '(10de:00C9)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 6600 GT',                         '(10de:00F1)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 6600',                            '(10de:00F2)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 6200',                            '(10de:00F3)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 6600 LE',                         '(10de:00F4)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 7800 GS',                         '(10de:00F5)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 6800 GS',                         '(10de:00F6)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 6800 Ultra',                      '(10de:00F9)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 6600 GT',                         '(10de:0140)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 6600',                            '(10de:0141)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 6600 LE',                         '(10de:0142)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 6600 VE',                         '(10de:0143)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce Go 6600',                         '(10de:0144)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 6610 XL',                         '(10de:0145)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce Go 6600 TE/6200 TE',              '(10de:0146)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 6700 XL',                         '(10de:0147)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce Go 6600',                         '(10de:0148)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce Go 6600 GT',                      '(10de:0149)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 6200',                            '(10de:014F)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 6500',                            '(10de:0160)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 6200 TurboCache(TM)',             '(10de:0161)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 6200SE TurboCache(TM)',           '(10de:0162)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 6200 LE',                         '(10de:0163)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce Go 6200',                         '(10de:0164)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce Go 6400',                         '(10de:0166)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce Go 6200',                         '(10de:0167)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce Go 6400',                         '(10de:0168)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 6250',                            '(10de:0169)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 7100 GS',                         '(10de:016A)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 8800 GTX',                        '(10de:0191)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 8800 GTS',                        '(10de:0193)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 8800 Ultra',                      '(10de:0194)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Tesla C870',                              '(10de:0197)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 7350 LE',                         '(10de:01D0)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 7300 LE',                         '(10de:01D1)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 7550 LE',                         '(10de:01D2)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 7300 SE/7200 GS',                 '(10de:01D3)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce Go 7200',                         '(10de:01D6)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce Go 7300',                         '(10de:01D7)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce Go 7400',                         '(10de:01D8)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 7500 LE',                         '(10de:01DD)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 7300 GS',                         '(10de:01DF)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 6200',                            '(10de:0221)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 6200 A-LE',                       '(10de:0222)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 6150',                            '(10de:0240)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 6150 LE',                         '(10de:0241)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 6100',                            '(10de:0242)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce Go 6150',                         '(10de:0244)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce Go 6100',                         '(10de:0247)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 7900 GTX',                        '(10de:0290)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 7900 GT/GTO',                     '(10de:0291)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 7900 GS',                         '(10de:0292)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 7950 GX2',                        '(10de:0293)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 7950 GX2',                        '(10de:0294)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 7950 GT',                         '(10de:0295)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce Go 7950 GTX',                     '(10de:0297)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce Go 7900 GS',                      '(10de:0298)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 7600 GT',                         '(10de:02E0)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 7600 GS',                         '(10de:02E1)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 7300 GT',                         '(10de:02E2)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 7900 GS',                         '(10de:02E3)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 7950 GT',                         '(10de:02E4)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 7650 GS',                         '(10de:038B)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 7650 GS',                         '(10de:0390)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 7600 GT',                         '(10de:0391)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 7600 GS',                         '(10de:0392)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 7300 GT',                         '(10de:0393)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 7600 LE',                         '(10de:0394)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 7300 GT',                         '(10de:0395)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce Go 7700',                         '(10de:0397)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce Go 7600',                         '(10de:0398)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce Go 7600 GT',                      '(10de:0399)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 6150SE nForce 430',               '(10de:03D0)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 6100 nForce 405',                 '(10de:03D1)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 6100 nForce 400',                 '(10de:03D2)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 6100 nForce 420',                 '(10de:03D5)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 7025 / nForce 630a',              '(10de:03D6)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 8600 GTS',                        '(10de:0400)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 8600 GT',                         '(10de:0401)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 8600 GT',                         '(10de:0402)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 8600 GS',                         '(10de:0403)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 8400 GS',                         '(10de:0404)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9500M GS',                        '(10de:0405)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 8300 GS',                         '(10de:0406)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 8600M GT',                        '(10de:0407)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9650M GS',                        '(10de:0408)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 8700M GT',                        '(10de:0409)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GT 330',                          '(10de:0410)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 8400 SE',                         '(10de:0420)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 8500 GT',                         '(10de:0421)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 8400 GS',                         '(10de:0422)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 8300 GS',                         '(10de:0423)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 8400 GS',                         '(10de:0424)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 8600M GS',                        '(10de:0425)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 8400M GT',                        '(10de:0426)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 8400M GS',                        '(10de:0427)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 8400M G',                         '(10de:0428)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9400 GT',                         '(10de:042C)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9300M G',                         '(10de:042E)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 7150M / nForce 630M',             '(10de:0531)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 7000M / nForce 610M',             '(10de:0533)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 7050 PV / nForce 630a',           '(10de:053A)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 7050 PV / nForce 630a',           '(10de:053B)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 7025 / nForce 630a',              '(10de:053E)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GTX 295',                         '(10de:05E0)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GTX 280',                         '(10de:05E1)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GTX 260',                         '(10de:05E2)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GTX 285',                         '(10de:05E3)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GTX 275',                         '(10de:05E6)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Tesla T10/M1060/C1060',                   '(10de:05E7)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GTX 260',                         '(10de:05EA)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GTX 295',                         '(10de:05EB)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 8800 GTS 512',                    '(10de:0600)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9800 GT',                         '(10de:0601)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 8800 GT',                         '(10de:0602)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GT 230',                          '(10de:0603)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9800 GX2',                        '(10de:0604)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9800 GT',                         '(10de:0605)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 8800 GS',                         '(10de:0606)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GTS 240',                         '(10de:0607)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9800M GTX',                       '(10de:0608)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 8800M GTS',                       '(10de:0609)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GTX 280M',                        '(10de:060A)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9800M GT',                        '(10de:060B)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 8800M GTX',                       '(10de:060C)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 8800 GS',                         '(10de:060D)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GTX 285M',                        '(10de:060F)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9600 GSO',                        '(10de:0610)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 8800 GT',                         '(10de:0611)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9800 GTX/9800 GTX+',              '(10de:0612)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9800 GTX+',                       '(10de:0613)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9800 GT',                         '(10de:0614)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GTS 250',                         '(10de:0615)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9800M GTX',                       '(10de:0617)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GTX 260M',                        '(10de:0618)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9600 GT',                         '(10de:0622)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9600 GS',                         '(10de:0623)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9600 GSO 512',                    '(10de:0625)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GT 130',                          '(10de:0626)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GT 140',                          '(10de:0627)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9800M GTS',                       '(10de:0628)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9700M GTS',                       '(10de:062A)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9800M GS',                        '(10de:062B)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9800M GTS',                       '(10de:062C)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9600 GT',                         '(10de:062D)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9600 GT',                         '(10de:062E)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GTS 160M',                        '(10de:0631)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GTS 150M',                        '(10de:0632)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9600 GSO',                        '(10de:0635)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9600 GT',                         '(10de:0637)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9500 GT',                         '(10de:0640)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9400 GT',                         '(10de:0641)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9500 GT',                         '(10de:0643)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9500 GS',                         '(10de:0644)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9500 GS',                         '(10de:0645)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GT 120',                          '(10de:0646)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9600M GT',                        '(10de:0647)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9600M GS',                        '(10de:0648)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9600M GT',                        '(10de:0649)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9700M GT',                        '(10de:064A)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9500M G',                         '(10de:064B)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9650M GT',                        '(10de:064C)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce G 110M',                          '(10de:0651)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GT 130M',                         '(10de:0652)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GT 120M',                         '(10de:0653)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GT 220M',                         '(10de:0654)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9650 S',                          '(10de:0656)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9400 GT',                         '(10de:065B)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GTX 480',                         '(10de:06C0)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GTX 465',                         '(10de:06C4)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GTX 480M',                        '(10de:06CA)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GTX 470',                         '(10de:06CD)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Tesla C2050 / C2070',                     '(10de:06D1)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Tesla M2070',                             '(10de:06D2)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Tesla T20 / M2050',                       '(10de:06DE)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Tesla M2070-Q',                           '(10de:06DF)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9300 GE',                         '(10de:06E0)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9300 GS',                         '(10de:06E1)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 8400',                            '(10de:06E2)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 8400 SE',                         '(10de:06E3)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 8400 GS',                         '(10de:06E4)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9300M GS',                        '(10de:06E5)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce G100',                            '(10de:06E6)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9300 SE',                         '(10de:06E7)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9200M GS',                        '(10de:06E8)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9300M GS',                        '(10de:06E9)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce G 105M',                          '(10de:06EC)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce G 103M',                          '(10de:06EF)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce G105M',                           '(10de:06F1)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 7150 / nForce 630i',              '(10de:07E0)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 7100 / nForce 630i',              '(10de:07E1)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 7050 / nForce 630i',              '(10de:07E2)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 7050 / nForce 610i',              '(10de:07E3)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 7050 / nForce 620i',              '(10de:07E5)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9100M G',                         '(10de:0844)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 8200M G',                         '(10de:0845)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9200',                            '(10de:0846)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9100',                            '(10de:0847)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 8300',                            '(10de:0848)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 8200',                            '(10de:0849)',  ['nvidia-graphics-drivers'] ),
    PciDevice('nForce 730a',                             '(10de:084A)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9200',                            '(10de:084B)',  ['nvidia-graphics-drivers'] ),
    PciDevice('nForce 980a/780a SLI',                    '(10de:084C)',  ['nvidia-graphics-drivers'] ),
    PciDevice('nForce 750a SLI',                         '(10de:084D)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 8100 / nForce 720a',              '(10de:084F)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9400',                            '(10de:0860)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9400',                            '(10de:0861)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9400M G',                         '(10de:0862)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9400M',                           '(10de:0863)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9300',                            '(10de:0864)',  ['nvidia-graphics-drivers'] ),
    PciDevice('ION',                                     '(10de:0865)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9400M G',                         '(10de:0866)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9400',                            '(10de:0867)',  ['nvidia-graphics-drivers'] ),
    PciDevice('nForce 760i SLI',                         '(10de:0868)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9400',                            '(10de:086A)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9300 / nForce 730i',              '(10de:086C)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9200',                            '(10de:086D)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9100M G',                         '(10de:086E)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 8200M G',                         '(10de:086F)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9400M',                           '(10de:0870)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9200',                            '(10de:0871)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce G102M',                           '(10de:0872)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce G102M',                           '(10de:0873)',  ['nvidia-graphics-drivers'] ),
    PciDevice('ION',                                     '(10de:0874)',  ['nvidia-graphics-drivers'] ),
    PciDevice('ION',                                     '(10de:0876)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 9400',                            '(10de:087A)',  ['nvidia-graphics-drivers'] ),
    PciDevice('ION',                                     '(10de:087D)',  ['nvidia-graphics-drivers'] ),
    PciDevice('ION LE',                                  '(10de:087E)',  ['nvidia-graphics-drivers'] ),
    PciDevice('ION LE',                                  '(10de:087F)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 320M',                            '(10de:08A5)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GT 220',                          '(10de:0A20)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 315',                             '(10de:0A22)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 210',                             '(10de:0A23)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 405',                             '(10de:0A26)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 405',                             '(10de:0A27)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GT 230M',                         '(10de:0A28)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GT 330M',                         '(10de:0A29)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GT 230M',                         '(10de:0A2A)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GT 330M',                         '(10de:0A2B)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GT 320M',                         '(10de:0A2D)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GT 240M',                         '(10de:0A34)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GT 325M',                         '(10de:0A35)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce G210',                            '(10de:0A60)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 205',                             '(10de:0A62)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 310',                             '(10de:0A63)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Second Generation ION',                   '(10de:0A64)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 210',                             '(10de:0A65)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 310',                             '(10de:0A66)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 315',                             '(10de:0A67)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce G105M',                           '(10de:0A68)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce G105M',                           '(10de:0A69)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 305M',                            '(10de:0A6E)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Second Generation ION',                   '(10de:0A6F)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 310M',                            '(10de:0A70)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 305M',                            '(10de:0A71)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 310M',                            '(10de:0A72)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 305M',                            '(10de:0A73)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce G210M',                           '(10de:0A74)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 310M',                            '(10de:0A75)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 315M',                            '(10de:0A7A)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GT 330',                          '(10de:0CA0)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GT 320',                          '(10de:0CA2)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GT 240',                          '(10de:0CA3)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GT 340',                          '(10de:0CA4)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GT 330',                          '(10de:0CA7)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GTS 260M',                        '(10de:0CA8)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GTS 250M',                        '(10de:0CA9)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GT 220',                          '(10de:0CAC)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GT 335M',                         '(10de:0CAF)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GTS 350M',                        '(10de:0CB0)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GTS 360M',                        '(10de:0CB1)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GT 440',                          '(10de:0DC0)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GTS 450',                         '(10de:0DC4)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GT 555M',                         '(10de:0DCD)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GTX 460M',                        '(10de:0DD1)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GT 445M',                         '(10de:0DD2)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GT 550M',                         '(10de:0DD6)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GT 440',                          '(10de:0DE0)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GT 430',                          '(10de:0DE1)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GT 420',                          '(10de:0DE2)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GT 530',                          '(10de:0DE5)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GT 525M',                         '(10de:0DEC)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GT 415M',                         '(10de:0DEE)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GT 425M',                         '(10de:0DF0)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GT 420M',                         '(10de:0DF1)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GT 435M',                         '(10de:0DF2)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GT 420M',                         '(10de:0DF3)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GT 540M',                         '(10de:0DF4)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GT 525M',                         '(10de:0DF5)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GT 550M',                         '(10de:0DF6)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GT 520M',                         '(10de:0DF7)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GTX 460',                         '(10de:0E22)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GTX 460 SE',                      '(10de:0E23)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GTX 460',                         '(10de:0E24)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GTX 470M',                        '(10de:0E30)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GTX 485M',                        '(10de:0E31)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GT 520',                          '(10de:1040)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GT 520M',                         '(10de:1050)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GTX 580',                         '(10de:1080)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GTX 570',                         '(10de:1081)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GTX 560 Ti',                      '(10de:1082)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GTX 590',                         '(10de:1088)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Tesla M2090',                             '(10de:1091)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Tesla M2075',                             '(10de:1094)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Tesla C2075',                             '(10de:1096)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 8400GS',                          '(10de:10C3)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 405',                             '(10de:10C5)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GTX 560 Ti',                      '(10de:1200)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GTX 560',                         '(10de:1201)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GT 545',                          '(10de:1241)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GTX 550 Ti',                      '(10de:1244)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GTS 450',                         '(10de:1245)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce GTX 560M',                        '(10de:1251)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro FX 4000',                          '(10de:004E)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro FX 4500',                          '(10de:009D)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro FX Go1400',                        '(10de:00CC)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro FX 3450/4000 SDI',                 '(10de:00CD)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro FX 1400',                          '(10de:00CE)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro FX 3400/Quadro FX 4000',           '(10de:00F8)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro NVS 440',                          '(10de:014A)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro FX 540M',                          '(10de:014C)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro FX 550',                           '(10de:014D)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro FX 540',                           '(10de:014E)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro NVS 285',                          '(10de:0165)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro FX 5600',                          '(10de:019D)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro FX 4600',                          '(10de:019E)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro NVS 110M',                         '(10de:01DA)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro NVS 120M',                         '(10de:01DB)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro FX 350M',                          '(10de:01DC)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro FX 350',                           '(10de:01DE)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro NVS 210S / GeForce 6150LE',        '(10de:0245)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro NVS 510M',                         '(10de:0299)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro FX 2500M',                         '(10de:029A)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro FX 1500M',                         '(10de:029B)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro FX 5500',                          '(10de:029C)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro FX 3500',                          '(10de:029D)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro FX 1500',                          '(10de:029E)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro FX 4500 X2',                       '(10de:029F)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro FX 560M',                          '(10de:039C)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro FX 560',                           '(10de:039E)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro FX 370',                           '(10de:040A)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro NVS 320M',                         '(10de:040B)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro FX 570M',                          '(10de:040C)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro FX 1600M',                         '(10de:040D)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro FX 570',                           '(10de:040E)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro FX 1700',                          '(10de:040F)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro NVS 140M',                         '(10de:0429)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro NVS 130M',                         '(10de:042A)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro NVS 135M',                         '(10de:042B)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro FX 360M',                          '(10de:042D)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro NVS 290',                          '(10de:042F)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadroplex 2200 D2',                      '(10de:05ED)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadroplex 2200 S4',                      '(10de:05F8)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro CX',                               '(10de:05F9)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro FX 5800',                          '(10de:05FD)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro FX 4800',                          '(10de:05FE)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro FX 3800',                          '(10de:05FF)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro FX 4700 X2',                       '(10de:0619)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro FX 3700',                          '(10de:061A)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro VX 200',                           '(10de:061B)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro FX 3600M',                         '(10de:061C)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro FX 2800M',                         '(10de:061D)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro FX 3700M',                         '(10de:061E)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro FX 3800M',                         '(10de:061F)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro FX 1800',                          '(10de:0638)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro FX 2700M',                         '(10de:063A)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro FX 380',                           '(10de:0658)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro FX 580',                           '(10de:0659)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro FX 1700M',                         '(10de:065A)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro FX 770M',                          '(10de:065C)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro 6000',                             '(10de:06D8)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro 5000',                             '(10de:06D9)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro 5000M',                            '(10de:06DA)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro 6000',                             '(10de:06DC)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro 4000',                             '(10de:06DD)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro NVS 150M',                         '(10de:06EA)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro NVS 160M',                         '(10de:06EB)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro NVS 420',                          '(10de:06F8)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro FX 370 LP',                        '(10de:06F9)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro NVS 450',                          '(10de:06FA)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro FX 370M',                          '(10de:06FB)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro NVS 295',                          '(10de:06FD)',  ['nvidia-graphics-drivers'] ),
    PciDevice('HICx16 + Graphics',                       '(10de:06FF)',  ['nvidia-graphics-drivers'] ),
    PciDevice('NVS 5100M',                               '(10de:0A2C)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro 400',                              '(10de:0A38)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro FX 880M',                          '(10de:0A3C)',  ['nvidia-graphics-drivers'] ),
    PciDevice('NVS 2100M',                               '(10de:0A6A)',  ['nvidia-graphics-drivers'] ),
    PciDevice('NVS 3100M',                               '(10de:0A6C)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro FX 380 LP',                        '(10de:0A78)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro FX 380M',                          '(10de:0A7C)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro FX 1800M',                         '(10de:0CBC)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro 2000',                             '(10de:0DD8)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro 2000M',                            '(10de:0DDA)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro 600',                              '(10de:0DF8)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro 1000M',                            '(10de:0DFA)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro 3000M',                            '(10de:0E3A)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro 4000M',                            '(10de:0E3B)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce 410M',                            '(10de:1055)',  ['nvidia-graphics-drivers'] ),
    PciDevice('NVS 4200M',                               '(10de:1056)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro 5010M',                            '(10de:109A)',  ['nvidia-graphics-drivers'] ),
    PciDevice('Quadro 7000',                             '(10de:109B)',  ['nvidia-graphics-drivers'] ),
    PciDevice('NVS 300',                                 '(10de:10D8)',  ['nvidia-graphics-drivers'] ),
    PciDevice('GeForce PCX 5750',                        '(10de:00FA)',  ['nvidia-graphics-drivers-173'] ),
    PciDevice('GeForce PCX 5900',                        '(10de:00FB)',  ['nvidia-graphics-drivers-173'] ),
    PciDevice('Quadro FX 330/GeForce PCX 5300',          '(10de:00FC)',  ['nvidia-graphics-drivers-173'] ),
    PciDevice('Quadro FX 330/Quadro NVS 280 PCI-E',      '(10de:00FD)',  ['nvidia-graphics-drivers-173'] ),
    PciDevice('Quadro FX 1300',                          '(10de:00FE)',  ['nvidia-graphics-drivers-173'] ),
    PciDevice('NV30',                                    '(10de:0301)',  ['nvidia-graphics-drivers-173'] ),
    PciDevice('NV30',                                    '(10de:0302)',  ['nvidia-graphics-drivers-173'] ),
    PciDevice('Quadro FX 2000',                          '(10de:0308)',  ['nvidia-graphics-drivers-173'] ),
    PciDevice('Quadro FX 1000',                          '(10de:0309)',  ['nvidia-graphics-drivers-173'] ),
    PciDevice('NV31',                                    '(10de:0311)',  ['nvidia-graphics-drivers-173'] ),
    PciDevice('NV31',                                    '(10de:0312)',  ['nvidia-graphics-drivers-173'] ),
    PciDevice('NV31',                                    '(10de:0314)',  ['nvidia-graphics-drivers-173'] ),
    PciDevice('NV31',                                    '(10de:031A)',  ['nvidia-graphics-drivers-173'] ),
    PciDevice('GeForce FX Go5650',                       '(10de:031B)',  ['nvidia-graphics-drivers-173'] ),
    PciDevice('Quadro FX Go700',                         '(10de:031C)',  ['nvidia-graphics-drivers-173'] ),
    PciDevice('NV34',                                    '(10de:0320)',  ['nvidia-graphics-drivers-173'] ),
    PciDevice('NV34',                                    '(10de:0321)',  ['nvidia-graphics-drivers-173'] ),
    PciDevice('NV34',                                    '(10de:0322)',  ['nvidia-graphics-drivers-173'] ),
    PciDevice('GeForce FX 5200LE',                       '(10de:0323)',  ['nvidia-graphics-drivers-173'] ),
    PciDevice('GeForce FX Go5200',                       '(10de:0324)',  ['nvidia-graphics-drivers-173'] ),
    PciDevice('GeForce FX Go5250',                       '(10de:0325)',  ['nvidia-graphics-drivers-173'] ),
    PciDevice('NV34',                                    '(10de:0326)',  ['nvidia-graphics-drivers-173'] ),
    PciDevice('GeForce FX 5100',                         '(10de:0327)',  ['nvidia-graphics-drivers-173'] ),
    PciDevice('GeForce FX Go5200 32M/64M',               '(10de:0328)',  ['nvidia-graphics-drivers-173'] ),
    PciDevice('Quadro NVS 55/280 PCI',                   '(10de:032A)',  ['nvidia-graphics-drivers-173'] ),
    PciDevice('Quadro FX 500/FX 600',                    '(10de:032B)',  ['nvidia-graphics-drivers-173'] ),
    PciDevice('GeForce FX Go53xx',                       '(10de:032C)',  ['nvidia-graphics-drivers-173'] ),
    PciDevice('GeForce FX Go5100',                       '(10de:032D)',  ['nvidia-graphics-drivers-173'] ),
    PciDevice('NV38',                                    '(10de:0330)',  ['nvidia-graphics-drivers-173'] ),
    PciDevice('NV35',                                    '(10de:0331)',  ['nvidia-graphics-drivers-173'] ),
    PciDevice('NV35',                                    '(10de:0332)',  ['nvidia-graphics-drivers-173'] ),
    PciDevice('NV38',                                    '(10de:0333)',  ['nvidia-graphics-drivers-173'] ),
    PciDevice('NV35',                                    '(10de:0334)',  ['nvidia-graphics-drivers-173'] ),
    PciDevice('Quadro FX 3000',                          '(10de:0338)',  ['nvidia-graphics-drivers-173'] ),
    PciDevice('Quadro FX 700',                           '(10de:033F)',  ['nvidia-graphics-drivers-173'] ),
    PciDevice('NV36',                                    '(10de:0341)',  ['nvidia-graphics-drivers-173'] ),
    PciDevice('NV36',                                    '(10de:0342)',  ['nvidia-graphics-drivers-173'] ),
    PciDevice('NV36',                                    '(10de:0343)',  ['nvidia-graphics-drivers-173'] ),
    PciDevice('NV36',                                    '(10de:0344)',  ['nvidia-graphics-drivers-173'] ),
    PciDevice('GeForce FX Go5700',                       '(10de:0347)',  ['nvidia-graphics-drivers-173'] ),
    PciDevice('GeForce FX Go5700',                       '(10de:0348)',  ['nvidia-graphics-drivers-173'] ),
    PciDevice('Quadro FX Go1000',                        '(10de:034C)',  ['nvidia-graphics-drivers-173'] ),
    PciDevice('Quadro FX 1100',                          '(10de:034E)',  ['nvidia-graphics-drivers-173'] ),
    PciDevice('NV11',                                    '(10de:0110)',  ['nvidia-graphics-drivers-96'] ),
    PciDevice('GeForce2 MX 100/200',                     '(10de:0111)',  ['nvidia-graphics-drivers-96'] ),
    PciDevice('GeForce2 Go',                             '(10de:0112)',  ['nvidia-graphics-drivers-96'] ),
    PciDevice('Quadro2 MXR/EX/Go',                       '(10de:0113)',  ['nvidia-graphics-drivers-96'] ),
    PciDevice('NV17',                                    '(10de:0170)',  ['nvidia-graphics-drivers-96'] ),
    PciDevice('NV17',                                    '(10de:0171)',  ['nvidia-graphics-drivers-96'] ),
    PciDevice('NV17',                                    '(10de:0172)',  ['nvidia-graphics-drivers-96'] ),
    PciDevice('NV18',                                    '(10de:0173)',  ['nvidia-graphics-drivers-96'] ),
    PciDevice('GeForce4 440 Go',                         '(10de:0174)',  ['nvidia-graphics-drivers-96'] ),
    PciDevice('GeForce4 420 Go',                         '(10de:0175)',  ['nvidia-graphics-drivers-96'] ),
    PciDevice('GeForce4 420 Go 32M',                     '(10de:0176)',  ['nvidia-graphics-drivers-96'] ),
    PciDevice('GeForce4 460 Go',                         '(10de:0177)',  ['nvidia-graphics-drivers-96'] ),
    PciDevice('Quadro4 550 XGL',                         '(10de:0178)',  ['nvidia-graphics-drivers-96'] ),
    PciDevice('GeForce4 440 Go 64M',                     '(10de:0179)',  ['nvidia-graphics-drivers-96'] ),
    PciDevice('Quadro NVS 400',                          '(10de:017A)',  ['nvidia-graphics-drivers-96'] ),
    PciDevice('Quadro4 500 GoGL',                        '(10de:017C)',  ['nvidia-graphics-drivers-96'] ),
    PciDevice('GeForce4 410 Go 16M',                     '(10de:017D)',  ['nvidia-graphics-drivers-96'] ),
    PciDevice('NV18',                                    '(10de:0181)',  ['nvidia-graphics-drivers-96'] ),
    PciDevice('GeForce4 MX 440SE-8X',                    '(10de:0182)',  ['nvidia-graphics-drivers-96'] ),
    PciDevice('GeForce4 MX 420-8X',                      '(10de:0183)',  ['nvidia-graphics-drivers-96'] ),
    PciDevice('NV18',                                    '(10de:0185)',  ['nvidia-graphics-drivers-96'] ),
    PciDevice('Quadro4 580 XGL',                         '(10de:0188)',  ['nvidia-graphics-drivers-96'] ),
    PciDevice('Quadro NVS 280 SD',                       '(10de:018A)',  ['nvidia-graphics-drivers-96'] ),
    PciDevice('Quadro4 380 XGL',                         '(10de:018B)',  ['nvidia-graphics-drivers-96'] ),
    PciDevice('Quadro NVS 50 PCI',                       '(10de:018C)',  ['nvidia-graphics-drivers-96'] ),
    PciDevice('NV1A',                                    '(10de:01A0)',  ['nvidia-graphics-drivers-96'] ),
    PciDevice('NV1F',                                    '(10de:01F0)',  ['nvidia-graphics-drivers-96'] ),
    PciDevice('NV20',                                    '(10de:0200)',  ['nvidia-graphics-drivers-96'] ),
    PciDevice('NV20',                                    '(10de:0201)',  ['nvidia-graphics-drivers-96'] ),
    PciDevice('NV20',                                    '(10de:0202)',  ['nvidia-graphics-drivers-96'] ),
    PciDevice('Quadro DCC',                              '(10de:0203)',  ['nvidia-graphics-drivers-96'] ),
    PciDevice('NV25',                                    '(10de:0250)',  ['nvidia-graphics-drivers-96'] ),
    PciDevice('NV25',                                    '(10de:0251)',  ['nvidia-graphics-drivers-96'] ),
    PciDevice('NV25',                                    '(10de:0253)',  ['nvidia-graphics-drivers-96'] ),
    PciDevice('Quadro4 900 XGL',                         '(10de:0258)',  ['nvidia-graphics-drivers-96'] ),
    PciDevice('Quadro4 750 XGL',                         '(10de:0259)',  ['nvidia-graphics-drivers-96'] ),
    PciDevice('Quadro4 700 XGL',                         '(10de:025B)',  ['nvidia-graphics-drivers-96'] ),
    PciDevice('NV28',                                    '(10de:0280)',  ['nvidia-graphics-drivers-96'] ),
    PciDevice('NV28',                                    '(10de:0281)',  ['nvidia-graphics-drivers-96'] ),
    PciDevice('NV28',                                    '(10de:0282)',  ['nvidia-graphics-drivers-96'] ),
    PciDevice('NV28',                                    '(10de:0286)',  ['nvidia-graphics-drivers-96'] ),
    PciDevice('Quadro4 980 XGL',                         '(10de:0288)',  ['nvidia-graphics-drivers-96'] ),
    PciDevice('Quadro4 780 XGL',                         '(10de:0289)',  ['nvidia-graphics-drivers-96'] ),
    PciDevice('Quadro4 700 GoGL',                        '(10de:028C)',  ['nvidia-graphics-drivers-96'] ),
    PciDevice('NV04',                                    '(10de:0020)',  ['nvidia-graphics-drivers-71'], supported=False ),
    PciDevice('NV05',                                    '(10de:0028)',  ['nvidia-graphics-drivers-71'], supported=False ),
    PciDevice('NV05',                                    '(10de:0029)',  ['nvidia-graphics-drivers-71'], supported=False ),
    PciDevice('NV06',                                    '(10de:002C)',  ['nvidia-graphics-drivers-71'], supported=False ),
    PciDevice('NV05',                                    '(10de:002D)',  ['nvidia-graphics-drivers-71'], supported=False ),
    PciDevice('Aladdin TNT2',                            '(10de:00A0)',  ['nvidia-graphics-drivers-71'], supported=False ),
    PciDevice('NV10',                                    '(10de:0100)',  ['nvidia-graphics-drivers-71'], supported=False ),
    PciDevice('NV10',                                    '(10de:0101)',  ['nvidia-graphics-drivers-71'], supported=False ),
    PciDevice('Quadro',                                  '(10de:0103)',  ['nvidia-graphics-drivers-71'], supported=False ),
    PciDevice('NV15',                                    '(10de:0150)',  ['nvidia-graphics-drivers-71'], supported=False ),
    PciDevice('NV15',                                    '(10de:0151)',  ['nvidia-graphics-drivers-71'], supported=False ),
    PciDevice('NV16',                                    '(10de:0152)',  ['nvidia-graphics-drivers-71'], supported=False ),
    PciDevice('Quadro2 Pro',                             '(10de:0153)',  ['nvidia-graphics-drivers-71'], supported=False ),
    ]

def get_pci_devices(text):
    regex_vga = re.compile('VGA compatible controller (.*)', re.IGNORECASE)

    devices = []
    lines = regex_vga.findall(text)
    if len(lines) > 0:
        for l in lines:
            line = l.strip()
            if len(line)>0:
                for device in pci_devices:
                    if device.rc.search(line):
                        devices.append(device)
    return devices


# For debugging
if __name__ == '__main__':
    from subprocess import Popen, PIPE
    
    pci_text = """
    00:02.0 VGA compatible controller [0300]: Intel Corporation Core Processor Integrated Graphics Controller [8086:0046] (rev 02) (prog-if 00 [VGA controller])
	Subsystem: Lenovo Device [17aa:215a]
	Control: I/O+ Mem+ BusMaster+ SpecCycle- MemWINV- VGASnoop- ParErr- Stepping- SERR- FastB2B- DisINTx+
	Status: Cap+ 66MHz- UDF- FastB2B+ ParErr- DEVSEL=fast >TAbort- <TAbort- <MAbort- >SERR- <PERR- INTx-
	Capabilities: [90] MSI: Enable+ Count=1/1 Maskable- 64bit-
		Address: fee0f00c  Data: 4171
	Kernel driver in use: i915
	Kernel modules: i915

    00:03.0 VGA compatible controller [0300]: Intel Corporation Core Processor Integrated Graphics Controller [8086:0042] (rev 02) (prog-if 00 [VGA controller])

    00:04.0 VGA compatible controller [0300]: Intel Corporation Core Processor Integrated Graphics Controller [8086:3582] (rev 02) (prog-if 00 [VGA controller])

    00:1c.2 PCI bridge [0604]: Intel Corporation 5 Series/3400 Series Chipset PCI Express Root Port 3 [8086:3b46] (rev 06) (prog-if 00 [Normal decode])
	Control: I/O+ Mem+ BusMaster+ SpecCycle- MemWINV- VGASnoop- ParErr- Stepping- SERR+ FastB2B- DisINTx-
	Status: Cap+ 66MHz- UDF- FastB2B- ParErr- DEVSEL=fast >TAbort- <TAbort- <MAbort- >SERR- <PERR- INTx-

        ff:02.3 Host bridge [0600]: Intel Corporation Core Processor Reserved [8086:2d13] (rev 02)
	Subsystem: Lenovo Device [17aa:2196]
	Control: I/O- Mem+ BusMaster+ SpecCycle- MemWINV- VGASnoop- ParErr- Stepping- SERR- FastB2B- DisINTx-
	Status: Cap- 66MHz- UDF- FastB2B- ParErr- DEVSEL=fast >TAbort- <TAbort- <MAbort- >SERR- <PERR- INTx-
	Latency: 0

        """
    
    for device in get_pci_devices(pci_text):
        print device.name, device.supported, ','.join(device.drivers)

    pci_text = Popen('lspci -vvnn', stdout=PIPE, shell=True).stdout.read()
    for device in get_pci_devices(pci_text):
        print device.name, device.supported, ','.join(device.drivers)
